@@ -88,8 +88,13 @@ working hour in `casual-timezone-planner'."
   :type 'string
   :group 'casual)
 
-(defcustom casual-timezone-zone-info-database "/usr/share/zoneinfo/tzdata.zi"
-  "Path to the tzdata.zi file used by `casual-timezone-zone-info'."
+(defcustom casual-timezone-zone-info-database
+  (file-name-concat (or (getenv "TZDIR") "/usr/share/zoneinfo")
+                    "tzdata.zi")
+  "Path to the tzdata.zi file used by `casual-timezone-zone-info'.
+
+Defaults to $TZDIR/tzdata.zi when the TZDIR environment variable
+is set and /usr/share/zoneinfo/tzdata.zi otherwise."
   :type 'file
   :group 'casual)
 
@@ -252,7 +257,6 @@ The format of the timestamp is defined in the variable
   "." #'casual-timezone-jump-to-relative-now
   "t" #'casual-timezone-planner-current-time
   "l" #'casual-timezone-planner-current-local
-  "r" #'casual-timezone-planner-current-remote
   "f" #'casual-timezone-planner-forward-day
   "b" #'casual-timezone-planner-backward-day
   "p" #'previous-line
@@ -518,7 +522,6 @@ window width has changed."
    ["Copy Time"
     ("t" "Times" casual-timezone-planner-current-time)
     ("l" "Local" casual-timezone-planner-current-local)
-    ;; ("r" "Remote" casual-timezone-planner-current-remote)
     ("T" "Point" casual-timezone-planner-current-point)]
 
    ["Misc"
